==> alchemite_apiclient-0.89.0.tar.gz: alchemite_apiclient-0.89.0/docs/AnalyseValidateResponse.md <==
# AnalyseValidateResponse


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**column_analytics** | [**[AnalyseValidateResponseColumnAnalytics]**](AnalyseValidateResponseColumnAnalytics.md) | Information about the predictions in each column.  Each object in the array corresponds to a column and is ordered according to the order in the given dataset. | 
**mean_validation_metric** | **float, none_type** | Mean validation metric across all non-descriptor columns (R^2 for continuous columns, MCC for categorical columns). Will be null if the validation metric for every column is null. | [optional] 
**mean_validation_metric_uncertainty** | **float, none_type** | Uncertainty in the mean validation metric across all non-descriptor columns (R^2 for continuous columns, MCC for categorical columns). Will be null if the validation metric for every column is null. | [optional] 
**median_validation_metric** | **float, none_type** | Median validation metric across all non-descriptor columns (R^2 for continuous columns, MCC for categorical columns). Will be null if the validation metric for every column is null. | [optional] 
**median_validation_metric_uncertainty** | **float, none_type** | Uncertainty in the median validation metric across all non-descriptor columns (R^2 for continuous columns, MCC for categorical columns). Will be null if the validation metric for every column is null. | [optional] 
**mean_coefficient_of_determination** | **float, none_type** | Mean coefficient of determination across all non-descriptor columns. Will be null if the coefficient of determination for every column is null. Deprecated, see &#x60;meanValidationMetric&#x60; for information on the mean performance of columns across all columns | [optional] 
**mean_coefficient_of_determination_uncertainty** | **float, none_type** | Uncertainty in the mean coefficient of determination across all non-descriptor columns. Will be null if the coefficient of determination for every column is null. Deprecated, see &#x60;meanValidationMetricUncertainty&#x60; for information on the uncertainty of the mean performance across all columns | [optional] 
**median_coefficient_of_determination** | **float, none_type** | Median coefficient of determination across all non-descriptor columns. Will be null if the coefficient of determination for every column is null. Deprecated, see &#x60;medianValidationMetric&#x60; for information on the median performance of columns across all columns | [optional] 
**median_coefficient_of_determination_uncertainty** | **float, none_type** | Uncertainty in the median coefficient of determination across all non-descriptor columns. Will be null if the coefficient of determination for every column is null. Deprecated, see &#x60;medianValidationMetricUncertainty&#x60; for information on the median performance of columns across all columns | [optional] 
**mean_rmse** | **float, none_type** | Mean root mean squared error across all non-descriptor columns. Will be null if the RMSE for every column is null. Deprecated, see &#x60;meanValidationMetric&#x60; for information on the mean performance of columns across all columns | [optional] 
**mean_rmse_uncertainty** | **float, none_type** | Uncertainty in the mean root mean squared error across all non-descriptor columns. Will be null if the RMSE for every column is null. Deprecated, see &#x60;meanValidationMetricUncertainty&#x60; for information on the uncertainty of the performance across all columns | [optional] 
**median_rmse** | **float, none_type** | Median root mean squared error across all non-descriptor columns. Will be null if the RMSE for every column is null. Deprecated, see &#x60;medianValidationMetric&#x60; for information on the median performance of columns across all columns | [optional] 
**median_rmse_uncertainty** | **float, none_type** | Uncertainty in the median root mean squared error across all non-descriptor columns. Will be null if the RMSE for every column is null. Deprecated, see &#x60;medianValidationMetricUncertainty&#x60; for information on the median performance of columns across all columns | [optional] 
**total_uncertainty_divergence** | **float, none_type** | The root mean square of all non-descriptor&#39;s &#x60;uncertaintyDivergence&#x60;. An indication of the extent to which the uncertainty associated with those columns deviate from the expected distribution of uncertainties. Values closer to 0 indicate closer match with the expected uncertainty distribution across all columns. | [optional] 
**predictions** | **str** | Only appears if returnPredictions is true. A CSV string containing one column of row headers plus three blocks of equally sized columns:   * The first row contains the column headers if returnColumnHeaders was True in the request   * The first column contains the row headers   * The 1st third of columns after the row headers contains the original values.   * The 2nd third of columns after the row headers contains the predictions for the original values.  The column headers in this block are the column names prefixed by &#x60;predicted_&#x60;.   * The 3rd third of columns after the row headers contains the uncertainties for the predicted values.  The column headers in the block are the column names prefixed by &#x60;uncertainty_&#x60;  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> alchemite_apiclient-0.96.0.tar.gz: alchemite_apiclient-0.96.0/docs/AnalyseValidateResponse.md <==
# AnalyseValidateResponse


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**column_analytics** | [**[AnalyseValidateResponseColumnAnalytics]**](AnalyseValidateResponseColumnAnalytics.md) | Information about the predictions in each column.  Each object in the array corresponds to a column and is ordered according to the order in the given dataset. | 
**mean_validation_metric** | **float, none_type** | Mean validation metric across all non-descriptor columns (R^2 for continuous and ordinal columns, MCC for categorical columns). Will be null if the validation metric for every column is null. | [optional] 
**mean_validation_metric_uncertainty** | **float, none_type** | Uncertainty in the mean validation metric across all non-descriptor columns (R^2 for continuous and ordinal columns, MCC for categorical columns). Will be null if the validation metric for every column is null. | [optional] 
**median_validation_metric** | **float, none_type** | Median validation metric across all non-descriptor columns (R^2 for continuous and ordinal columns, MCC for categorical columns). Will be null if the validation metric for every column is null. | [optional] 
**median_validation_metric_uncertainty** | **float, none_type** | Uncertainty in the median validation metric across all non-descriptor columns (R^2 for continuous and ordinal columns, MCC for categorical columns). Will be null if the validation metric for every column is null. | [optional] 
**mean_coefficient_of_determination** | **float, none_type** | Mean coefficient of determination across all non-descriptor columns. Will be null if the coefficient of determination for every column is null. Deprecated, see &#x60;meanValidationMetric&#x60; for information on the mean performance of columns across all columns | [optional] 
**mean_coefficient_of_determination_uncertainty** | **float, none_type** | Uncertainty in the mean coefficient of determination across all non-descriptor columns. Will be null if the coefficient of determination for every column is null. Deprecated, see &#x60;meanValidationMetricUncertainty&#x60; for information on the uncertainty of the mean performance across all columns | [optional] 
**median_coefficient_of_determination** | **float, none_type** | Median coefficient of determination across all non-descriptor columns. Will be null if the coefficient of determination for every column is null. Deprecated, see &#x60;medianValidationMetric&#x60; for information on the median performance of columns across all columns | [optional] 
**median_coefficient_of_determination_uncertainty** | **float, none_type** | Uncertainty in the median coefficient of determination across all non-descriptor columns. Will be null if the coefficient of determination for every column is null. Deprecated, see &#x60;medianValidationMetricUncertainty&#x60; for information on the median performance of columns across all columns | [optional] 
**mean_rmse** | **float, none_type** | Mean root mean squared error across all non-descriptor columns. Will be null if the RMSE for every column is null. Deprecated, see &#x60;meanValidationMetric&#x60; for information on the mean performance of columns across all columns | [optional] 
**mean_rmse_uncertainty** | **float, none_type** | Uncertainty in the mean root mean squared error across all non-descriptor columns. Will be null if the RMSE for every column is null. Deprecated, see &#x60;meanValidationMetricUncertainty&#x60; for information on the uncertainty of the performance across all columns | [optional] 
**median_rmse** | **float, none_type** | Median root mean squared error across all non-descriptor columns. Will be null if the RMSE for every column is null. Deprecated, see &#x60;medianValidationMetric&#x60; for information on the median performance of columns across all columns | [optional] 
**median_rmse_uncertainty** | **float, none_type** | Uncertainty in the median root mean squared error across all non-descriptor columns. Will be null if the RMSE for every column is null. Deprecated, see &#x60;medianValidationMetricUncertainty&#x60; for information on the median performance of columns across all columns | [optional] 
**total_uncertainty_divergence** | **float, none_type** | The root mean square of all non-descriptor&#39;s &#x60;uncertaintyDivergence&#x60;. An indication of the extent to which the uncertainty associated with those columns deviate from the expected distribution of uncertainties. Values closer to 0 indicate closer match with the expected uncertainty distribution across all columns. | [optional] 
**predictions** | **str** | Only appears if returnPredictions is true. A CSV string containing one column of row headers plus three blocks of equally sized columns:   * The first row contains the column headers if returnColumnHeaders was True in the request   * The first column contains the row headers   * The 1st third of columns after the row headers contains the original values.   * The 2nd third of columns after the row headers contains the predictions for the original values.  The column headers in this block are the column names prefixed by &#x60;predicted_&#x60;.   * The 3rd third of columns after the row headers contains the uncertainties for the predicted values.  The column headers in the block are the column names prefixed by &#x60;uncertainty_&#x60;  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
